==> kari-0.23.tar.gz: kari-0.23/alyson/urlentry.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtk.h>
#include "neve.h"
#include "lisa.h"
#include "smg.h"
#include "alyson.h"
#include "utils.h"
#include "urlentry.h"

/*****************************************************************************
 * function  : urlentry_init
 * arguments : 
 * results   : a URL entry widget
 * purpose   : sets up the URL entry widget
 * caveats   : 
 ***************************************************************************** */

GtkWidget *
urlentry_init (void)
{

  GtkWidget *entry;

  entry = gtk_entry_new_with_max_length (512);
  gtk_signal_connect (GTK_OBJECT (entry), "activate",
		      GTK_SIGNAL_FUNC (enter_callback),
		      entry);
  gtk_entry_set_text (GTK_ENTRY (entry), "");

  return entry;

}

/*****************************************************************************
 * function  : urlentry_update
 * arguments : URL entry widget and the URL to use
 * results   : 
 * purpose   : Updates the URL entry widget to reflect the current link
 * caveats   : 
 ***************************************************************************** */

void
urlentry_update (GtkWidget *entry, char *url)
{
  debug (debug_alyson, "updating to \"%s\"", url);
  gtk_entry_set_text (GTK_ENTRY (entry), url);
}

/*****************************************************************************
 * function  : enter_callback
 * arguments : widget (?) and URL entry widget
 * results   : 
 * purpose   : handles alteration of the URL entry widget
 * caveats   : WTF is the first argument?  GTK+ clearly needs it
 ***************************************************************************** */

void
enter_callback (GtkWidget * widget, GtkWidget * entry)
{
  gchar *entry_text;
  BrowserWindow *cole;
  GtkLisa *lisa;

  entry_text = gtk_entry_get_text (GTK_ENTRY (entry));
  debug (debug_alyson, "Entry contents: %s\n", entry_text);
  cole = help_me_bob();
  lisa = GTK_LISA (cole->lisa);

  strcpy (lisa->current_path, "/");
  do_doc (lisa, entry_text);

}

==> kari-0.30.tar.gz: kari-0.30/alyson/urlentry.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtk.h>
#include "neve.h"
#include "lisa.h"
#include "smg.h"
#include "alyson.h"
#include "utils.h"
#include "urlentry.h"
#include "url.h"
#include "chloe.h"
#include "parser.h"

/*****************************************************************************
 * function  : urlentry_init
 * arguments : 
 * results   : a URL entry widget
 * purpose   : sets up the URL entry widget
 * caveats   : 
 ***************************************************************************** */

GtkWidget *
urlentry_init (void)
{

  GtkWidget *entry;

  entry = gtk_entry_new_with_max_length (512);
  gtk_signal_connect (GTK_OBJECT (entry), "activate",
		      GTK_SIGNAL_FUNC (enter_callback),
		      entry);
  gtk_entry_set_text (GTK_ENTRY (entry), "");

  return entry;

}

/*****************************************************************************
 * function  : urlentry_update
 * arguments : URL entry widget and the URL to use
 * results   : 
 * purpose   : Updates the URL entry widget to reflect the current link
 * caveats   : 
 ***************************************************************************** */

void
urlentry_update (GtkWidget *entry, char *url)
{
  debug (debug_alyson, "updating to \"%s\"", url);
  gtk_entry_set_text (GTK_ENTRY (entry), url);
}

/*****************************************************************************
 * function  : enter_callback
 * arguments : widget (?) and URL entry widget
 * results   : 
 * purpose   : handles alteration of the URL entry widget
 * caveats   : WTF is the first argument?  GTK+ clearly needs it
 ***************************************************************************** */

void
enter_callback (GtkWidget * widget, GtkWidget * entry)
{
  gchar *entry_text;
  BrowserWindow *paula;
  char *body;
  int i;

  entry_text = gtk_entry_get_text (GTK_ENTRY (entry));
  debug (debug_alyson, "Entry contents: %s\n", entry_text);
  paula = help_me_bob();
  i = parse_url (entry_text, paula);
  if (i < 0)
    fubar (NONSYS, "parse_url died?  I'm not setup to cope with this.  I have _issues_.");
  body = get_html_file (paula);
  parse_html (body, paula);
  free (body);

}
